@@ -4,19 +4,31 @@ def get_webhooks(client):
 
 
 def update_webhooks_url(client, hooks, new_url):
+    results = []
     for hook in hooks:
+        url = f'{client.api_path}/webhooks/{hook["id"]}.json'
         payload = {
                 "webhook": {
                     "id": hook['id'],
                     "address": new_url
                     }
                 }
-        client.put(f'{client.api_path}/webhooks/{hook["id"]}.json', json=payload)
+        results.append(client.put(url, json=payload).json())
+    return results
 
 
-def cancel_order(client, order_number):
+def get_order_risks(client, order_number):
+    uri = f'{client.api_path}/orders/{order_number}/risks.json'
+    return client.get(uri).json()['risks']
+
+
+def create_cancel_options():
+    pass
+
+
+def cancel_order(client, order_number, options=None):
     uri = f'{client.api_path}/orders/{order_number}/cancel.json'
-    return client.post(uri).json()
+    return client.post(uri, json=options).json()
 
 
 def get_fulfillment_orders(client, order_number):
